//////////////////////////////////////////////////////////////////////////////
//
//  Xilinx, Inc. 2002                 www.xilinx.com
//
//  XAPP 224 - Data Recovery
//
//////////////////////////////////////////////////////////////////////////////
//
//  File name :       top_ve.v
//
//  Description :     Generic top level file to use data recovery module in a VirtexE,
// 		      uses one dcm to generate two 90 degree phased clocks at up to 160 MHz.
//
//  Date - revision : December 6th 2004 - v 2.3
//
//  Author :          NJS
//
//  Contact : e-mail  hotline@xilinx.com
//            phone   + 1 800 255 7778 
//
//  Disclaimer: LIMITED WARRANTY AND DISCLAMER. These designs are
//              provided to you "as is". Xilinx and its licensors make and you
//              receive no warranties or conditions, express, implied,
//              statutory or otherwise, and Xilinx specifically disclaims any
//              implied warranties of merchantability, non-infringement,or
//              fitness for a particular purpose. Xilinx does not warrant that
//              the functions contained in these designs will meet your
//              requirements, or that the operation of these designs will be
//              uninterrupted or error free, or that defects in the Designs
//              will be corrected. Furthermore, Xilinx does not warrantor
//              make any representations regarding use or the results of the
//              use of the designs in terms of correctness, accuracy,
//              reliability, or otherwise.
//
//              LIMITATION OF LIABILITY. In no event will Xilinx or its
//              licensors be liable for any loss of data, lost profits,cost
//              or procurement of substitute goods or services, or for any
//              special, incidental, consequential, or indirect damages
//              arising from the use or operation of the designs or
//              accompanying documentation, however caused and on any theory
//              of liability. This limitation will apply even if Xilinx
//              has been advised of the possibility of such damage. This
//              limitation shall apply not-withstanding the failure of the
//              essential purpose of any limited remedies herein.
//
//  Copyright  2002 Xilinx, Inc.
//  All rights reserved
//
//////////////////////////////////////////////////////////////////////////////
//
`timescale 1 ps / 1ps

module top_ve (
	clkin,				// clock input
	rstin,				// reset input
	datain,			 	// data input
	dummy,				// dummy output for recovered data
	dvalid,				// recovered data valid when high
	locked) ;			// DLL locked

input 		clkin, rstin, datain ;
	
output 	[1:0] 	dummy, dvalid ;
output 		locked ;
reg 	[1:0] 	dummy, dvalid;

wire 		clk ;
wire 		clkdllo	;
wire 		clkint;
wire 		clk90;
wire 		clk90dllo;
wire 	[1:0] 	dummyint ;
wire 	[1:0] 	dvalidint ;

CLKDLL dll1(
	.CLKIN	(clkint),
	.CLKFB	(clk),
	.RST	(rstin),
	.CLK0	(clkdllo),
	.CLK90	(clk90dllo),
	.LOCKED	(locked));
	
IBUFG ibufg1(.I(clkin), .O(clkint) );

BUFG bufg1(.I(clkdllo), .O(clk) );
BUFG bufg2(.I(clk90dllo), .O(clk90) );

data_recovery_virtexe drmodule (
	.data	(datain),
	.rst	(rstin),
	.clk	(clk),
	.clk90	(clk90),
	.sdata	(dummyint),
	.dv	(dvalidint) );
		
always @(posedge clk or posedge rstin)
begin
if (rstin)
begin
	dummy = 2'b00;
	dvalid = 2'b00;
end
else
begin
	dummy = dummyint;
	dvalid = dvalidint;
end
end
endmodule


